import 'package:dio/dio.dart';
import 'package:flutter/foundation.dart';

class Client {
  String baseURL;
  Map<String, dynamic>? headers;
  bool showLogging;
  Client({required this.baseURL, this.headers, this.showLogging = true});

  Dio init() {
    var dio = Dio();
    dio.options.baseUrl = baseURL;
    dio.options.connectTimeout = const Duration(seconds: 120);
    dio.options.receiveTimeout = const Duration(seconds: 120);
    dio.options.headers = headers;
    dio.interceptors.add(ApiInterceptors(showLogging: showLogging));
    return dio;
  }
}

class ApiInterceptors extends Interceptor {
  bool showLogging;

  ApiInterceptors({this.showLogging = true});
  @override
  void onRequest(RequestOptions options, RequestInterceptorHandler handler) {
    if (showLogging) {
      if (kDebugMode) {
        print('REQUEST[${options.method}] => PATH: ${options.path}');
        print('DATA BODY: [${options.data}]');
      }
    }
    return super.onRequest(options, handler);
  }

  @override
  void onResponse(Response response, ResponseInterceptorHandler handler) {
    if (showLogging) {
      if (kDebugMode) {
        print('RESPONSE[${response.statusCode}] => PATH: ${response.requestOptions.path}');
      }
    }
    return super.onResponse(response, handler);
  }

  @override
  void onError(DioException err, ErrorInterceptorHandler handler) async {
    if (showLogging) {
      if (kDebugMode) {
        print('ERROR[${err.response?.statusCode}] => PATH: ${err.requestOptions.path}');
        print('ERROR MESSAGE : ${err.message}');
      }
    }

    return super.onError(err, handler);
  }
}
